==> kubernetes-model-resource-6.6.0-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimStatusFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimStatusFluent<A extends ResourceClaimStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAllocation instead.
   * @return The buildable object.
   */
  @Deprecated
  public AllocationResult getAllocation();
  public AllocationResult buildAllocation();
  public A withAllocation(AllocationResult allocation);
  public Boolean hasAllocation();
  public ResourceClaimStatusFluent.AllocationNested<A> withNewAllocation();
  public ResourceClaimStatusFluent.AllocationNested<A> withNewAllocationLike(AllocationResult item);
  public ResourceClaimStatusFluent.AllocationNested<A> editAllocation();
  public ResourceClaimStatusFluent.AllocationNested<A> editOrNewAllocation();
  public ResourceClaimStatusFluent.AllocationNested<A> editOrNewAllocationLike(AllocationResult item);
  public Boolean getDeallocationRequested();
  public A withDeallocationRequested(Boolean deallocationRequested);
  public Boolean hasDeallocationRequested();
  public String getDriverName();
  public A withDriverName(String driverName);
  public Boolean hasDriverName();
  public A addToReservedFor(Integer index,ResourceClaimConsumerReference item);
  public A setToReservedFor(Integer index,ResourceClaimConsumerReference item);
  public A addToReservedFor(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimConsumerReference... items);
  public A addAllToReservedFor(Collection<ResourceClaimConsumerReference> items);
  public A removeFromReservedFor(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimConsumerReference... items);
  public A removeAllFromReservedFor(Collection<ResourceClaimConsumerReference> items);
  public A removeMatchingFromReservedFor(Predicate<ResourceClaimConsumerReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildReservedFor instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ResourceClaimConsumerReference> getReservedFor();
  public List<ResourceClaimConsumerReference> buildReservedFor();
  public ResourceClaimConsumerReference buildReservedFor(Integer index);
  public ResourceClaimConsumerReference buildFirstReservedFor();
  public ResourceClaimConsumerReference buildLastReservedFor();
  public ResourceClaimConsumerReference buildMatchingReservedFor(Predicate<ResourceClaimConsumerReferenceBuilder> predicate);
  public Boolean hasMatchingReservedFor(Predicate<ResourceClaimConsumerReferenceBuilder> predicate);
  public A withReservedFor(List<ResourceClaimConsumerReference> reservedFor);
  public A withReservedFor(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimConsumerReference... reservedFor);
  public Boolean hasReservedFor();
  public A addNewReservedFor(String apiGroup,String name,String resource,String uid);
  public ResourceClaimStatusFluent.ReservedForNested<A> addNewReservedFor();
  public ResourceClaimStatusFluent.ReservedForNested<A> addNewReservedForLike(ResourceClaimConsumerReference item);
  public ResourceClaimStatusFluent.ReservedForNested<A> setNewReservedForLike(Integer index,ResourceClaimConsumerReference item);
  public ResourceClaimStatusFluent.ReservedForNested<A> editReservedFor(Integer index);
  public ResourceClaimStatusFluent.ReservedForNested<A> editFirstReservedFor();
  public ResourceClaimStatusFluent.ReservedForNested<A> editLastReservedFor();
  public ResourceClaimStatusFluent.ReservedForNested<A> editMatchingReservedFor(Predicate<ResourceClaimConsumerReferenceBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withDeallocationRequested();
  public interface AllocationNested<N> extends Nested<N>,AllocationResultFluent<ResourceClaimStatusFluent.AllocationNested<N>>{
    public N and();
    public N endAllocation();
    
  }
  public interface ReservedForNested<N> extends Nested<N>,ResourceClaimConsumerReferenceFluent<ResourceClaimStatusFluent.ReservedForNested<N>>{
    public N and();
    public N endReservedFor();
    
  }
  
}

==> kubernetes-model-resource-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/resource/v1alpha1/ResourceClaimStatusFluent.java <==
package io.fabric8.kubernetes.api.model.resource.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ResourceClaimStatusFluent<A extends ResourceClaimStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAllocation instead.
   * @return The buildable object.
   */
  @Deprecated
  public AllocationResult getAllocation();
  public AllocationResult buildAllocation();
  public A withAllocation(AllocationResult allocation);
  public Boolean hasAllocation();
  public ResourceClaimStatusFluent.AllocationNested<A> withNewAllocation();
  public ResourceClaimStatusFluent.AllocationNested<A> withNewAllocationLike(AllocationResult item);
  public ResourceClaimStatusFluent.AllocationNested<A> editAllocation();
  public ResourceClaimStatusFluent.AllocationNested<A> editOrNewAllocation();
  public ResourceClaimStatusFluent.AllocationNested<A> editOrNewAllocationLike(AllocationResult item);
  public Boolean getDeallocationRequested();
  public A withDeallocationRequested(Boolean deallocationRequested);
  public Boolean hasDeallocationRequested();
  public String getDriverName();
  public A withDriverName(String driverName);
  public Boolean hasDriverName();
  public A addToReservedFor(int index,ResourceClaimConsumerReference item);
  public A setToReservedFor(int index,ResourceClaimConsumerReference item);
  public A addToReservedFor(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimConsumerReference... items);
  public A addAllToReservedFor(Collection<ResourceClaimConsumerReference> items);
  public A removeFromReservedFor(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimConsumerReference... items);
  public A removeAllFromReservedFor(Collection<ResourceClaimConsumerReference> items);
  public A removeMatchingFromReservedFor(Predicate<ResourceClaimConsumerReferenceBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildReservedFor instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ResourceClaimConsumerReference> getReservedFor();
  public List<ResourceClaimConsumerReference> buildReservedFor();
  public ResourceClaimConsumerReference buildReservedFor(int index);
  public ResourceClaimConsumerReference buildFirstReservedFor();
  public ResourceClaimConsumerReference buildLastReservedFor();
  public ResourceClaimConsumerReference buildMatchingReservedFor(Predicate<ResourceClaimConsumerReferenceBuilder> predicate);
  public Boolean hasMatchingReservedFor(Predicate<ResourceClaimConsumerReferenceBuilder> predicate);
  public A withReservedFor(List<ResourceClaimConsumerReference> reservedFor);
  public A withReservedFor(io.fabric8.kubernetes.api.model.resource.v1alpha1.ResourceClaimConsumerReference... reservedFor);
  public Boolean hasReservedFor();
  public A addNewReservedFor(String apiGroup,String name,String resource,String uid);
  public ResourceClaimStatusFluent.ReservedForNested<A> addNewReservedFor();
  public ResourceClaimStatusFluent.ReservedForNested<A> addNewReservedForLike(ResourceClaimConsumerReference item);
  public ResourceClaimStatusFluent.ReservedForNested<A> setNewReservedForLike(int index,ResourceClaimConsumerReference item);
  public ResourceClaimStatusFluent.ReservedForNested<A> editReservedFor(int index);
  public ResourceClaimStatusFluent.ReservedForNested<A> editFirstReservedFor();
  public ResourceClaimStatusFluent.ReservedForNested<A> editLastReservedFor();
  public ResourceClaimStatusFluent.ReservedForNested<A> editMatchingReservedFor(Predicate<ResourceClaimConsumerReferenceBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withDeallocationRequested();
  public interface AllocationNested<N> extends Nested<N>,AllocationResultFluent<ResourceClaimStatusFluent.AllocationNested<N>>{
    public N and();
    public N endAllocation();
    
  }
  public interface ReservedForNested<N> extends Nested<N>,ResourceClaimConsumerReferenceFluent<ResourceClaimStatusFluent.ReservedForNested<N>>{
    public N and();
    public N endReservedFor();
    
  }
  
}
